<?php

namespace Guru\Offer\Http\Requests;

use App\Http\Requests\Request as FormRequest;
use Illuminate\Http\Request;

class OfferUserApiRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(Request $request)
    {
        $offer = $this->route('offer');
        if (is_null($offer)) {
            // Determine if the user is authorized to access offer module,
            return $request->user('api')->canDo('offer.offer.view');
        }

        if ($request->isMethod('POST') || $request->is('*/create')) {
            // Determine if the user is authorized to create an entry,
            return $request->user('api')->can('create', $offer);
        }

        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            // Determine if the user is authorized to update an entry,
            return $request->user('api')->can('update', $offer);
        }

        if ($request->isMethod('DELETE')) {
            // Determine if the user is authorized to delete an entry,
            return $request->user('api')->can('delete', $offer);
        }

        // Determine if the user is authorized to view the module.
        return $request->user('api')->can('view', $offer);

    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(Request $request)
    {
        if ($request->isMethod('POST')) {
            // validation rule for create request.
            return [
                'name'                => 'required',
            ];
        }
        
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            // Validation rule for update request.
            return [
                'name'                => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
