<?php

namespace Guru\Offer\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Guru\Offer\Models\Offer;

class OfferPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the offer.
     *
     * @param User $user
     * @param Offer $offer
     *
     * @return bool
     */
    public function view(User $user, Offer $offer)
    {
        if ($user->canDo('offer.offer.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $offer->user_id;
    }

    /**
     * Determine if the given user can create a offer.
     *
     * @param User $user
     * @param Offer $offer
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('offer.offer.create');
    }

    /**
     * Determine if the given user can update the given offer.
     *
     * @param User $user
     * @param Offer $offer
     *
     * @return bool
     */
    public function update(User $user, Offer $offer)
    {
        if ($user->canDo('offer.offer.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $offer->user_id;
    }

    /**
     * Determine if the given user can delete the given offer.
     *
     * @param User $user
     * @param Offer $offer
     *
     * @return bool
     */
    public function destroy(User $user, Offer $offer)
    {
        if ($user->canDo('offer.offer.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $offer->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
